MapsEntry

Struct MapsEntry 

pub(super) struct MapsEntry {
    address: (usize, usize),
    offset: u64,
    pathname: OsString,
}

Fields

address: (usize, usize)

start (inclusive) and limit (exclusive) of address range.

offset: u64

Offset into the file (or “whatever”).

pathname: OsString

Usually the file backing the mapping.

Note: The man page for proc includes a note about “coordination” by using readelf to see the Offset field in ELF program headers. pnkfelix is not yet sure if that is intended to be a comment on pathname, or what form/purpose such coordination is meant to have.

There are also some pseudo-paths: “[stack]”: The initial process’s (aka main thread’s) stack. “[stack:]”: a specific thread’s stack. (This was only present for a limited range of Linux verisons; it was determined to be too expensive to provide.) “[vdso]”: Virtual dynamically linked shared object “[heap]”: The process’s heap

The pathname can be blank, which means it is an anonymous mapping obtained via mmap.

Newlines in pathname are replaced with an octal escape sequence.

The pathname may have “(deleted)” appended onto it if the file-backed path has been deleted.

Note that modifications like the latter two indicated above imply that in general the pathname may be ambiguous. (I.e. you cannot tell if the denoted filename actually ended with the text “(deleted)”, or if that was added by the maps rendering.

Implementations

Source

impl MapsEntry

pub(super) fn pathname(&self) -> &OsString

pub(super) fn ip_matches(&self, ip: usize) -> bool